@@ -1,12 +1,21 @@
 """
 This module contains enumerations used in pyproj.
 """
-from enum import Enum
+from enum import Enum, IntFlag
 
 
 class BaseEnum(Enum):
+    """
+    Base enumeration class that handles
+    input as strings ignoring case.
+    """
+
     @classmethod
     def create(cls, item):
+        """
+        Handles finding the enumeration
+        ignoring case if provided as a string.
+        """
         try:
             return cls(item)
         except ValueError:
@@ -17,10 +26,8 @@ class BaseEnum(Enum):
             if member.value == item:
                 return member
         raise ValueError(
-            "Invalid value supplied '{}'. "
-            "Only {} are supported.".format(
-                item, tuple(version.value for version in cls)
-            )
+            f"Invalid value supplied '{item}'. "
+            f"Only {tuple(version.value for version in cls)} are supported."
         )
 
 
@@ -35,10 +42,14 @@ class WktVersion(BaseEnum):
     WKT2_2015 = "WKT2_2015"
     #: WKT Version 2 from 2015 Simplified
     WKT2_2015_SIMPLIFIED = "WKT2_2015_SIMPLIFIED"
-    #: WKT Version 2 from 2018
+    #: Deprecated alias for WKT Version 2 from 2019
     WKT2_2018 = "WKT2_2018"
-    #: WKT Version 2 from 2018 Simplified
+    #: Deprecated alias for WKT Version 2 from 2019 Simplified
     WKT2_2018_SIMPLIFIED = "WKT2_2018_SIMPLIFIED"
+    #: WKT Version 2 from 2019
+    WKT2_2019 = "WKT2_2019"
+    #: WKT Version 2 from 2019 Simplified
+    WKT2_2019_SIMPLIFIED = "WKT2_2019_SIMPLIFIED"
     #: WKT Version 1 GDAL Style
     WKT1_GDAL = "WKT1_GDAL"
     #: WKT Version 1 ESRI Style
@@ -77,7 +88,7 @@ class PJType(BaseEnum):
     """
     .. versionadded:: 2.4.0
 
-    PJ Types for listing codes with :func:`~pyproj.get_codes`
+    PJ Types for listing codes with :func:`pyproj.get_codes`
 
     Attributes
     ----------
@@ -134,3 +145,23 @@ class PJType(BaseEnum):
     TRANSFORMATION = "TRANSFORMATION"
     CONCATENATED_OPERATION = "CONCATENATED_OPERATION"
     OTHER_COORDINATE_OPERATION = "OTHER_COORDINATE_OPERATION"
+
+
+class GeodIntermediateFlag(IntFlag):
+    """
+    .. versionadded:: 3.1.0
+
+    Flags to be used in Geod.[inv|fwd]_intermediate()
+    """
+
+    DEFAULT = 0x0
+
+    NPTS_ROUND = 0x0
+    NPTS_CEIL = 0x1
+    NPTS_TRUNC = 0x2
+
+    DEL_S_RECALC = 0x00
+    DEL_S_NO_RECALC = 0x10
+
+    AZIS_DISCARD = 0x000
+    AZIS_KEEP = 0x100
